from typing import Any

class ADC:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def read_u16(self, *args, **kwargs) -> Any: ...

DEEPSLEEP: int
DEEPSLEEP_RESET: int
HARD_RESET: int

class I2C:
    def __init__(self, *argv, **kwargs) -> None: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def start(self, *args, **kwargs) -> Any: ...
    def stop(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def readfrom(self, *args, **kwargs) -> Any: ...
    def readfrom_into(self, *args, **kwargs) -> Any: ...
    def readfrom_mem(self, *args, **kwargs) -> Any: ...
    def readfrom_mem_into(self, *args, **kwargs) -> Any: ...
    def scan(self, *args, **kwargs) -> Any: ...
    def writeto(self, *args, **kwargs) -> Any: ...
    def writeto_mem(self, *args, **kwargs) -> Any: ...
    def writevto(self, *args, **kwargs) -> Any: ...

class PWM:
    def __init__(self, *argv, **kwargs) -> None: ...
    def deinit(self, *args, **kwargs) -> Any: ...
    def duty(self, *args, **kwargs) -> Any: ...
    def freq(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...

PWRON_RESET: int

class Pin:
    def __init__(self, *argv, **kwargs) -> None: ...
    def value(self, *args, **kwargs) -> Any: ...
    IN: int
    IRQ_FALLING: int
    IRQ_RISING: int
    OPEN_DRAIN: int
    OUT: int
    PULL_UP: int
    def init(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def off(self, *args, **kwargs) -> Any: ...
    def on(self, *args, **kwargs) -> Any: ...

class RTC:
    def __init__(self, *argv, **kwargs) -> None: ...
    ALARM0: int
    def alarm(self, *args, **kwargs) -> Any: ...
    def alarm_left(self, *args, **kwargs) -> Any: ...
    def datetime(self, *args, **kwargs) -> Any: ...
    def irq(self, *args, **kwargs) -> Any: ...
    def memory(self, *args, **kwargs) -> Any: ...

SOFT_RESET: int

class SPI:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    LSB: int
    MSB: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def write_readinto(self, *args, **kwargs) -> Any: ...

class Signal:
    def __init__(self, *argv, **kwargs) -> None: ...
    def value(self, *args, **kwargs) -> Any: ...
    def off(self, *args, **kwargs) -> Any: ...
    def on(self, *args, **kwargs) -> Any: ...

class SoftI2C:
    def __init__(self, *argv, **kwargs) -> None: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def start(self, *args, **kwargs) -> Any: ...
    def stop(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def readfrom(self, *args, **kwargs) -> Any: ...
    def readfrom_into(self, *args, **kwargs) -> Any: ...
    def readfrom_mem(self, *args, **kwargs) -> Any: ...
    def readfrom_mem_into(self, *args, **kwargs) -> Any: ...
    def scan(self, *args, **kwargs) -> Any: ...
    def writeto(self, *args, **kwargs) -> Any: ...
    def writeto_mem(self, *args, **kwargs) -> Any: ...
    def writevto(self, *args, **kwargs) -> Any: ...

class SoftSPI:
    def __init__(self, *argv, **kwargs) -> None: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    LSB: int
    MSB: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...
    def write_readinto(self, *args, **kwargs) -> Any: ...

class Timer:
    def __init__(self, *argv, **kwargs) -> None: ...
    ONE_SHOT: int
    PERIODIC: int
    def deinit(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...

class UART:
    def __init__(self, *argv, **kwargs) -> None: ...
    def any(self, *args, **kwargs) -> Any: ...
    def read(self, *args, **kwargs) -> Any: ...
    def readinto(self, *args, **kwargs) -> Any: ...
    def readline(self, *args, **kwargs) -> Any: ...
    def write(self, *args, **kwargs) -> Any: ...
    def init(self, *args, **kwargs) -> Any: ...

class WDT:
    def __init__(self, *argv, **kwargs) -> None: ...
    def deinit(self, *args, **kwargs) -> Any: ...
    def feed(self, *args, **kwargs) -> Any: ...

WDT_RESET: int

def bitstream(*args, **kwargs) -> Any: ...
def deepsleep(*args, **kwargs) -> Any: ...
def disable_irq(*args, **kwargs) -> Any: ...
def enable_irq(*args, **kwargs) -> Any: ...
def freq(*args, **kwargs) -> Any: ...
def idle(*args, **kwargs) -> Any: ...
def lightsleep(*args, **kwargs) -> Any: ...

mem16: Any
mem32: Any
mem8: Any

def reset(*args, **kwargs) -> Any: ...
def reset_cause(*args, **kwargs) -> Any: ...
def sleep(*args, **kwargs) -> Any: ...
def soft_reset(*args, **kwargs) -> Any: ...
def time_pulse_us(*args, **kwargs) -> Any: ...
def unique_id(*args, **kwargs) -> Any: ...
