from typing import Any

class Entry:
    time: Any
    obj: Any
    userdata: Any
    def __init__(self, time, obj, userdata) -> None: ...
    def __lt__(self, another): ...

class utimeq:
    heap: Any
    max_sz: Any
    def __init__(self, sz) -> None: ...
    def __bool__(self): ...
    def push(self, time, obj, userdata): ...
    def pop(self, arr) -> None: ...
    def peektime(self): ...
    def remove(self, id) -> None: ...
