from typing import Any

class Response:
    raw: Any
    encoding: str
    _cached: Any
    def __init__(self, f) -> None: ...
    def close(self) -> None: ...
    @property
    def content(self): ...
    @property
    def text(self): ...
    def json(self): ...

def request(method, url, data: Any | None = ..., json: Any | None = ..., headers=..., stream: Any | None = ...): ...
def head(url, **kw): ...
def get(url, **kw): ...
def post(url, **kw): ...
def put(url, **kw): ...
def patch(url, **kw): ...
def delete(url, **kw): ...
