from typing import Any

def collect(*args, **kwargs) -> Any: ...
def disable(*args, **kwargs) -> Any: ...
def enable(*args, **kwargs) -> Any: ...
def isenabled(*args, **kwargs) -> Any: ...
def mem_alloc(*args, **kwargs) -> Any: ...
def mem_free(*args, **kwargs) -> Any: ...
def threshold(*args, **kwargs) -> Any: ...
