from typing import Any

argv: list
byteorder: str

def exit(*args, **kwargs) -> Any: ...

implementation: tuple
maxsize: int
modules: dict
path: list
platform: str

def print_exception(*args, **kwargs) -> Any: ...

stderr: Any
stdin: Any
stdout: Any
version: str
version_info: tuple
