from typing import Any

class array:
    def __init__(self, *argv, **kwargs) -> None: ...
    def append(self, *args, **kwargs) -> Any: ...
    def extend(self, *args, **kwargs) -> Any: ...
    def decode(self, *args, **kwargs) -> Any: ...
