from typing import Any

class sha1:
    def __init__(self, *argv, **kwargs) -> None: ...
    def update(self, *args, **kwargs) -> Any: ...
    def digest(self, *args, **kwargs) -> Any: ...

class sha256:
    def __init__(self, *argv, **kwargs) -> None: ...
    def update(self, *args, **kwargs) -> Any: ...
    def digest(self, *args, **kwargs) -> Any: ...
