from typing import Any

def calcsize(*args, **kwargs) -> Any: ...
def pack(*args, **kwargs) -> Any: ...
def pack_into(*args, **kwargs) -> Any: ...
def unpack(*args, **kwargs) -> Any: ...
def unpack_from(*args, **kwargs) -> Any: ...
