from typing import Any

def gmtime(*args, **kwargs) -> Any: ...
def localtime(*args, **kwargs) -> Any: ...
def mktime(*args, **kwargs) -> Any: ...
def sleep(*args, **kwargs) -> Any: ...
def sleep_ms(*args, **kwargs) -> Any: ...
def sleep_us(*args, **kwargs) -> Any: ...
def ticks_add(*args, **kwargs) -> Any: ...
def ticks_cpu(*args, **kwargs) -> Any: ...
def ticks_diff(*args, **kwargs) -> Any: ...
def ticks_ms(*args, **kwargs) -> Any: ...
def ticks_us(*args, **kwargs) -> Any: ...
def time(*args, **kwargs) -> Any: ...
def time_ns(*args, **kwargs) -> Any: ...
