"""
Module: 'time' on micropython-v1.18-esp8266
"""
# MCU: {'ver': 'v1.18', 'port': 'esp8266', 'arch': 'xtensa', 'sysname': 'esp8266', 'release': '1.18', 'name': 'micropython', 'mpy': 9733, 'version': '1.18', 'machine': 'ESP module with ESP8266', 'build': '', 'nodename': 'esp8266', 'platform': 'esp8266', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any


def gmtime(*args, **kwargs) -> Any:
    ...


def localtime(*args, **kwargs) -> Any:
    ...


def mktime(*args, **kwargs) -> Any:
    ...


def sleep(*args, **kwargs) -> Any:
    ...


def sleep_ms(*args, **kwargs) -> Any:
    ...


def sleep_us(*args, **kwargs) -> Any:
    ...


def ticks_add(*args, **kwargs) -> Any:
    ...


def ticks_cpu(*args, **kwargs) -> Any:
    ...


def ticks_diff(*args, **kwargs) -> Any:
    ...


def ticks_ms(*args, **kwargs) -> Any:
    ...


def ticks_us(*args, **kwargs) -> Any:
    ...


def time(*args, **kwargs) -> Any:
    ...


def time_ns(*args, **kwargs) -> Any:
    ...
