"""
Module: 'math' on micropython-v1.18-esp8266
"""
# MCU: {'ver': 'v1.18', 'port': 'esp8266', 'arch': 'xtensa', 'sysname': 'esp8266', 'release': '1.18', 'name': 'micropython', 'mpy': 9733, 'version': '1.18', 'machine': 'ESP module with ESP8266', 'build': '', 'nodename': 'esp8266', 'platform': 'esp8266', 'family': 'micropython'}
# Stubber: 1.5.4
from typing import Any


def pow(*args, **kwargs) -> Any:
    ...


def acos(*args, **kwargs) -> Any:
    ...


def asin(*args, **kwargs) -> Any:
    ...


def atan(*args, **kwargs) -> Any:
    ...


def atan2(*args, **kwargs) -> Any:
    ...


def ceil(*args, **kwargs) -> Any:
    ...


def copysign(*args, **kwargs) -> Any:
    ...


def cos(*args, **kwargs) -> Any:
    ...


def degrees(*args, **kwargs) -> Any:
    ...


e = 2.71828  # type: float


def exp(*args, **kwargs) -> Any:
    ...


def fabs(*args, **kwargs) -> Any:
    ...


def floor(*args, **kwargs) -> Any:
    ...


def fmod(*args, **kwargs) -> Any:
    ...


def frexp(*args, **kwargs) -> Any:
    ...


def isfinite(*args, **kwargs) -> Any:
    ...


def isinf(*args, **kwargs) -> Any:
    ...


def isnan(*args, **kwargs) -> Any:
    ...


def ldexp(*args, **kwargs) -> Any:
    ...


def log(*args, **kwargs) -> Any:
    ...


def modf(*args, **kwargs) -> Any:
    ...


pi = 3.14159  # type: float


def radians(*args, **kwargs) -> Any:
    ...


def sin(*args, **kwargs) -> Any:
    ...


def sqrt(*args, **kwargs) -> Any:
    ...


def tan(*args, **kwargs) -> Any:
    ...


def trunc(*args, **kwargs) -> Any:
    ...
